/*******************************************************************************
 * Stefan Meyer, 2012
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.atemsource.atem.api.type;


import org.apache.commons.lang.ArrayUtils;
import org.atemsource.atem.api.BusinessException;


/**
 * a typed entity {@link Object#publish()}, but the entity of any of the cascadingly also published entities is not
 * valid. The affending entities are included in the exception.
 * 
 * @author Thomas Jacob.
 */
public class PublishingException extends BusinessException
{
	/**
	 * The invalid entities that aborted the operation.
	 */
	private Object[] invalidEntities;

	/**
	 * Creates a new staging exception.
	 * 
	 * @param message The message describing the problem situation.
	 * @param invalidEntities The invalid entities that aborted the operation.
	 */
	public PublishingException(final String message, final Object[] invalidEntities)
	{
		super(message);
		this.invalidEntities = invalidEntities;
	}

	/**
	 * Creates a new staging exception.
	 * 
	 * @param message The message describing the problem situation.
	 * @param cause The root cause (a <code>Throwable</code>) of the problem.
	 * @param invalidEntities The invalid entities that aborted the operation.
	 */
	public PublishingException(final String message, final Throwable cause, final Object[] invalidEntities)
	{
		super(message, cause);
		this.invalidEntities = invalidEntities;
	}

	/**
	 * Returns the invalid entities that aborted the operation.
	 * 
	 * @return The invalid entities.
	 */
	public Object[] getInvalidEntities()
	{
		return invalidEntities;
	}

	@Override
	public String toString()
	{
		if (ArrayUtils.isEmpty(invalidEntities))
		{
			return super.toString();
		}

		StringBuffer buffer = new StringBuffer(super.toString());
		buffer.append(" (invalid entities: ");

		boolean first = true;
		for (Object entity : invalidEntities)
		{
			if (first)
			{
				first = false;
			}
			else
			{
				buffer.append(", ");
			}

			buffer.append(entity);
		}
		buffer.append(")");

		return buffer.toString();
	}
}
